require 'nvim-treesitter.configs'.setup {
    ensure_installed = 'all',
    ignore_install = { 'comment' },
    sync_install = true,
    highlight = {
        enable = true,
        additional_vim_regex_highlighting = { 'org' }
    },
    context_commentstring = {
        enable = true,
        enable_autocmd = false -- handled by Comment
    }
}

require('orgmode').setup {}
require('orgmode').setup_ts_grammar()

vim.api.nvim_create_augroup('config_fileformats', { clear = true })
vim.api.nvim_create_autocmd({ 'FileType' }, {
    group = 'config_fileformats',
    pattern = { 'org' },
    callback = function()
        -- allow to hide stuff, like links
        vim.opt_local.conceallevel = 2
        vim.opt_local.concealcursor = 'nc'
    end
})

vim.api.nvim_create_autocmd({ 'FileType' }, {
    group = 'config_fileformats',
    pattern = { 'gentoo-package-*' },
    command = [[set tabstop=2 shiftwidth=2]]
})

vim.api.nvim_create_autocmd({ 'BufEnter' }, {
    group = 'config_fileformats',
    pattern = { '*.m3u8', '*.m3u' },
    command = [[set textwidth=0]]
})

require("todo-comments").setup({
    signs = false,
    highlight = {
        keyword = 'bg',
        after = ''
    }
})

vim.g.vimtex_compiler_latexmk_engines = { _ = '-xelatex' }

require('colorizer').setup({
    filetypes = { '*' },
    user_default_options = {
        mode = 'virtualtext',
        rgb_fn = true,
        hsl_fn = true,
        RRGGBBAA = true,
    }
})
